@@ -2,11 +2,7 @@
 import sys
 import time
 
-try:
-    from unittest2.runner import TextTestRunner
-except ImportError:
-    from unittest import TextTestRunner
-
+from .unittest import TextTestRunner
 from .result import _XMLTestResult
 
 try:
@@ -16,28 +12,9 @@ except ImportError:
     from io import StringIO
 
 
-class _DelegateIO(object):
-    """
-    This class defines an object that captures whatever is written to
-    a stream or file.
-    """
-
-    def __init__(self, delegate):
-        self._captured = StringIO()
-        self.delegate = delegate
-
-    def write(self, text):
-        self._captured.write(text)
-        self.delegate.write(text)
-
-    def __getattr__(self, attr):
-        try:
-            return getattr(self._captured, attr)
-        except AttributeError:
-            return getattr(self.delegate, attr)
-
-    def reset(self):
-        self._captured = StringIO()
+# see issue #74, the encoding name needs to be one of
+# http://www.iana.org/assignments/character-sets/character-sets.xhtml
+UTF8 = 'UTF-8'
 
 
 class XMLTestRunner(TextTestRunner):
@@ -46,9 +23,9 @@ class XMLTestRunner(TextTestRunner):
     """
     def __init__(self, output='.', outsuffix=None, stream=sys.stderr,
                  descriptions=True, verbosity=1, elapsed_times=True,
-                 failfast=False, encoding='utf8'):
+                 failfast=False, buffer=False, encoding=UTF8):
         TextTestRunner.__init__(self, stream, descriptions, verbosity,
-                                failfast=failfast)
+                                failfast=failfast, buffer=buffer)
         self.verbosity = verbosity
         self.output = output
         self.encoding = encoding
@@ -67,28 +44,12 @@ class XMLTestRunner(TextTestRunner):
             self.stream, self.descriptions, self.verbosity, self.elapsed_times
         )
 
-    def _patch_standard_output(self):
-        """
-        Replaces stdout and stderr streams with string-based streams
-        in order to capture the tests' output.
-        """
-        sys.stdout = _DelegateIO(sys.stdout)
-        sys.stderr = _DelegateIO(sys.stderr)
-
-    def _restore_standard_output(self):
-        """
-        Restores stdout and stderr streams.
-        """
-        sys.stdout = sys.stdout.delegate
-        sys.stderr = sys.stderr.delegate
-
     def run(self, test):
         """
         Runs the given test case or test suite.
         """
         try:
             # Prepare the test execution
-            self._patch_standard_output()
             result = self._make_result()
             if hasattr(test, 'properties'):
                 # junit testsuite properties
@@ -153,6 +114,6 @@ class XMLTestRunner(TextTestRunner):
             self.stream.writeln('Generating XML reports...')
             result.generate_reports(self)
         finally:
-            self._restore_standard_output()
+            pass
 
         return result
